---
name: Feature Request
about: A suggestion that I might want to implement myself
---

### Describe the feature you would like

### Suggested implementation

### Describe alternatives that you have considered
